@@ -48,9 +48,9 @@ EXAMPLE = f"{GREEN}\n\
 EXAMPLE:\n\
 \tRefactor foo function in ...\n{CYAN}\
 <body is optional, adding it leave an empty line here>\n{GREEN}\
-\t- Fix ...\n\
-\t- Add ...\n\
-\t- Remove ...\n{YELLOW}\
+\t* Fix ...\n\
+\t* Add ...\n\
+\t* Remove ...\n{YELLOW}\
 hint:\tto read chaos-hum team rules visit: {BLUE}{GITHUB_LINK}{OFF}\n"
 
 
